@@ -16,4 +16,16 @@ impl FCD<'_> {
             .send_cmd_url::<HashMap<String, Decimal>>(self.fcd_url, "/v1/txs/gas_prices", None)
             .await?)
     }
+    pub async fn fetch_gas_prices(
+        client: &reqwest::Client,
+        fcd_url: &str,
+    ) -> anyhow::Result<HashMap<String, Decimal>> {
+        Ok(Terra::fetch_url::<HashMap<String, Decimal>>(
+            client,
+            fcd_url,
+            "/v1/txs/gas_prices",
+            None,
+        )
+        .await?)
+    }
 }
