@@ -1,9 +1,5 @@
-use crate::client::staking_types::{
-    ValidatorDelegationResult, ValidatorListResult, ValidatorResult,
-    ValidatorUnbondingDelegationResult,
-};
-use crate::staking_types::Validator;
-use crate::Terra;
+use crate::client::staking_types::{Validator, ValidatorDelegation, ValidatorUnbondingDelegation};
+use crate::{LCDResult, Terra};
 
 pub struct Staking<'a> {
     terra: &'a Terra<'a>,
@@ -12,22 +8,22 @@ impl Staking<'_> {
     pub fn create<'a>(terra: &'a Terra) -> Staking<'a> {
         Staking { terra }
     }
-    pub async fn validator(&self, key: &str) -> anyhow::Result<ValidatorResult> {
+    pub async fn validator(&self, key: &str) -> anyhow::Result<LCDResult<Validator>> {
         //   let url = self.terra.url.to_owned() + "/staking/validators/" + key;
         self.terra
-            .send_cmd::<ValidatorResult>("/staking/validators/", Some(key))
+            .send_cmd::<LCDResult<Validator>>("/staking/validators/", Some(key))
             .await
     }
     /// Get list of validators
-    pub async fn validators(&self) -> anyhow::Result<ValidatorListResult> {
+    pub async fn validators(&self) -> anyhow::Result<LCDResult<Vec<Validator>>> {
         self.terra
-            .send_cmd::<ValidatorListResult>("/staking/validators", None)
+            .send_cmd::<LCDResult<Vec<Validator>>>("/staking/validators", None)
             .await
     }
     pub async fn validator_by_moniker(&self, moniker: &str) -> anyhow::Result<Option<Validator>> {
         let lst = self
             .terra
-            .send_cmd::<ValidatorListResult>("/staking/validators", None)
+            .send_cmd::<LCDResult<Vec<Validator>>>("/staking/validators", None)
             .await?
             .result;
         match lst.iter().find(|&p| p.description.moniker == moniker) {
@@ -39,9 +35,9 @@ impl Staking<'_> {
     pub async fn validator_delegations(
         &self,
         key: &str,
-    ) -> anyhow::Result<ValidatorDelegationResult> {
+    ) -> anyhow::Result<LCDResult<Vec<ValidatorDelegation>>> {
         self.terra
-            .send_cmd::<ValidatorDelegationResult>(
+            .send_cmd::<LCDResult<Vec<ValidatorDelegation>>>(
                 &format!("/staking/validators/{}/delegations", key),
                 None,
             )
@@ -52,9 +48,9 @@ impl Staking<'_> {
     pub async fn validator_unbonding_delegations(
         &self,
         key: &str,
-    ) -> anyhow::Result<ValidatorUnbondingDelegationResult> {
+    ) -> anyhow::Result<LCDResult<Vec<ValidatorUnbondingDelegation>>> {
         self.terra
-            .send_cmd::<ValidatorUnbondingDelegationResult>(
+            .send_cmd::<LCDResult<Vec<ValidatorUnbondingDelegation>>>(
                 &format!("/staking/validators/{}/unbonding_delegations", key),
                 None,
             )
